import csv
from datetime import date

from django.conf import settings
from django.http import StreamingHttpResponse
from reportserver.lib.io import responses


def get_filename(exportname, extension):
    program = settings.PROGRAM.upper()
    today = str(date.today())
    if exportname == "Teilnahmen":
        exportname = "Rohdaten-Teilnahmen"
    return program + "_" + exportname + "_" + today + "." + extension


def export_csv(rows, exportname):
    """
    exports rows as plain CSV
    :param rows:
    :return:
    """
    pseudo_buffer = responses.Pseudobuffer()
    writer = csv.writer(pseudo_buffer)
    stream = StreamingHttpResponse((writer.writerow(
                                    responses.encode_row(sanify_row(row)))
                                    for row in rows),
                                   content_type="text/csv")
    stream['Content-Disposition'] = \
        'attachment; filename="%s"' % get_filename(exportname, "csv")
    return stream


def sanify_row(row):
    """Loop thru values of a row and sanify each value."""
    return [sanify_value(value) for value in row]


def sanify_value(value):
    """Sanify a value. Boolean to 1/0 None to '' else do nothing."""
    if value is True:
        return 1
    elif value is False:
        return 0
    elif value is None:
        return ''
    else:
        return value
